==> HostCMS.Free_6.7.tar.gz: modules/benchmark/i18n/en.php <==
<?php
/**
 * Benchmark.
 *
 * @package HostCMS
 * @subpackage Benchmark
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Benchmark',
	'menu' => 'Benchmark',
	'menu_speed' => 'Speed',
	'menu_rate' => 'Check',
	'menu_site_speed' => 'Site speed',
	'title' => 'Benchmark',
	'mbps' => '%s Mbps',
	'download_speed' => 'Download speed',
	'email' => 'Email',
	'email_val' => '%s sec.',
	'cpu_string' => 'CPU, string',
	'cpu_math' => 'CPU, math',
	'filesystem' => 'File system',
	'bd_change' => 'DB, update',
	'bd_read' => 'DB, read',
	'bd_write' => 'DB, write',
	'server' => 'Server',
	'etalon' => 'Standard',
	'benchmark' => 'Benchmark',
	'check_success' => 'Check benchmark success',
	'markDeleted_success' => 'Deleted success',
	'waiting_time' => 'Waiting answer',
	'load_page_time' => 'Load page',
	'dns_lookup' => 'DNS lookup',
	'connect_server' => 'Server connection',
	'start_monitoring' => 'Turn on performance monitor',
	'reset' => 'Reset',
	'benchmark_day' => 'Performance by days',
	'benchmark_hour' => 'Performance by hours',

	'cache' => 'Cache',
	'cache_description' => 'Cashing systems significantly reduce the load of the server and time of page generation speeding up page loading.',

	'compression' => 'Compression',
	'compression_description' => 'Compresses the site pages transmitted to visitors speeding up site loading. Union, minify and compress CSS and Javascript.',
	'speedUp' => 'Speed Up Performance',
	'database' => 'Database',
	'tableEngines' => 'Table Engines',
	'severalEnginesMsg' => 'The database contains tables with different engines!',
	'changeStorageEnginesTitle' => 'Setting the Storage Engine',
	'engine' => 'Engine',
	'count' => 'Count',
	'chooseStorageEnginesMsg' => 'Select the storage engine for tables. Do not forget to backup your database!',
	'convert' => 'Convert',
	'convertedMsg' => 'Changed Storage Engines: %s.',
);

==> HostCMS.Free_7.0.tar.gz: modules/benchmark/i18n/en.php <==
<?php
/**
 * Benchmark.
 *
 * @package HostCMS
 * @subpackage Benchmark
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2021 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Benchmark',
	'menu' => 'Benchmark',
	'menu_speed' => 'Speed',
	'menu_rate' => 'Check',
	'menu_site_speed' => 'Site speed',
	'title' => 'Benchmark',
	'mbps' => '%s Mbps',
	'download_speed' => 'Download speed',
	'email' => 'Email',
	'email_val' => '%s sec.',
	'cpu_string' => 'CPU, string',
	'cpu_math' => 'CPU, math',
	'filesystem' => 'File system',
	'bd_change' => 'DB, update',
	'bd_read' => 'DB, read',
	'bd_write' => 'DB, write',
	'server' => 'Server',
	'etalon' => 'Standard',
	'benchmark' => 'Benchmark',
	'check_success' => 'Check benchmark success',
	'markDeleted_success' => 'Deleted success',
	'waiting_time' => 'Waiting answer',
	'load_page_time' => 'Load page',
	'dns_lookup' => 'DNS lookup',
	'connect_server' => 'Server connection',
	'start_monitoring' => 'Turn on performance monitor',
	'reset' => 'Reset',
	'benchmark_day' => 'Performance by days',
	'benchmark_hour' => 'Performance by hours',

	'cache' => 'Cache',
	'cache_description' => 'Cashing systems significantly reduce the load of the server and time of page generation speeding up page loading.',

	'compression' => 'Compression',
	'compression_description' => 'Compresses the site pages transmitted to visitors speeding up site loading. Union, minify and compress CSS and Javascript.',
	'speedUp' => 'Speed Up Performance',
	'database' => 'Database',
	'tableEngines' => 'Table Engines',
	'severalEnginesMsg' => 'The database contains tables with different engines!',
	'changeStorageEnginesTitle' => 'Setting the Storage Engine',
	'engine' => 'Engine',
	'count' => 'Count',
	'changeMsg' => 'Do not forget to backup your database!',
	'convert' => 'Convert',
	'convertedMsg' => 'Changed Storage Engines: %s.',
	'add_counter' => 'Insert benchmark code into template',
	'tableCharsets' => 'Table Charsets',
	'severalCharsetsMsg' => 'The database contains tables with different charsets!',
	'changeStorageCharsetTitle' => 'Setting charset',

	'option_database_table_name' => 'Name of the table in the database',
	'option_database_write_query_count' => 'Number of write requests',
	'option_database_read_query_count' => 'Number of read requests',
	'option_database_change_query_count' => 'Number of change requests',
	'option_sample_text' => 'Sample text',
	'option_files_count' => 'Number of files',
	'option_math_count' => 'Number of calculations',
	'option_string_count' => 'Number of rows',
	'option_benchmark_file_path' => 'Path to download file',
);
